yt.visualization.volume_rendering.camera.FisheyeCamera.switch_view — The yt Project 3.2-dev documentation

# yt.visualization.volume_rendering.camera.FisheyeCamera.switch_view

`FisheyeCamera.` `switch_view`(normal_vector=None, width=None, center=None, north_vector=None)

  Change the view based on any of the view parameters.

  This will recalculate the orientation and width based on any of normal_vector, width, center, and north_vector.

  Parameters: | normal_vector: array_like, optional : The new looking vector. width: float or array of floats, optional : The new width. Can be a single value W -> [W,W,W] or an array [W1, W2, W3] (left/right, top/bottom, front/back) center: array_like, optional : Specifies the new center. north_vector : array_like, optional The ‘up’ direction for the plane of rays. If not specific, calculated automatically.